@@ -82,7 +82,7 @@ ios_dev_file_convert_flags (int mode_flags, char **mode_for_fdopen)
     }
   else
     /* Cannot open a file neither to write nor to read.  */
-    return 0;
+    return -1;
 
   if (mode_flags & IOS_F_CREATE)
     flags_for_open |= O_CREAT;
@@ -107,7 +107,7 @@ ios_dev_file_open (const char *handler, uint64_t flags, void **dev)
       /* Decide what mode to use to open the file.  */
       flags_for_open
         = ios_dev_file_convert_flags (mode_flags, &mode_for_fdopen);
-      if (flags_for_open == 0)
+      if (flags_for_open == -1)
         {
           internal_error = IOD_EFLAGS;
           goto err;
@@ -120,7 +120,8 @@ ios_dev_file_open (const char *handler, uint64_t flags, void **dev)
   else
     {
       /* Try read-write initially.
-         If that fails, then try read-only. */
+         If that fails, then try read-only.
+         If that fails, then try write-only.  */
       f = fopen (handler, "r+b");
       flags |= (IOS_F_READ | IOS_F_WRITE);
       if (!f)
@@ -128,6 +129,11 @@ ios_dev_file_open (const char *handler, uint64_t flags, void **dev)
           f = fopen (handler, "rb");
           flags &= ~IOS_F_WRITE;
         }
+      if (!f)
+        {
+          f = fopen (handler, "w");
+          flags = IOS_F_WRITE;
+        }
     }
 
   if (!f)
@@ -198,11 +204,17 @@ ios_dev_file_pread (void *iod, void *buf, size_t count, ios_dev_off offset)
     return IOD_EOF;
   ret = fread (buf, 1, count, fio->file);
 
+  if (ferror (fio->file))
+    {
+      clearerr (fio->file);
+      return IOD_ERROR;
+    }
+
   /* XXX As long as count <= 9 because the ios layer reads at most an
      unaligned uint64_t, we are unlikely to hit short reads.  But if
      future code adds in large buffer reads, we may want to retry on
      short reads rather than giving up right away. */
-  return ret == count ? 0 : IOD_EOF;
+  return ret == count ? IOD_OK : IOD_EOF;
 }
 
 static int
@@ -218,7 +230,14 @@ ios_dev_file_pwrite (void *iod, const void *buf, size_t count,
     return IOD_EOF;
   ret = fwrite (buf, 1, count, fio->file);
 
-  return ret == count ? 0 : IOD_EOF;
+  if (ferror (fio->file))
+    {
+      perror ("write: ");
+      clearerr (fio->file);
+      return IOD_ERROR;
+    }
+
+  return ret == count ? IOD_OK : IOD_EOF;
 }
 
 static ios_dev_off
