@@ -21,11 +21,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <dejagnu.h>
 #include <err.h>
 #include "read-file.h"
 #include "libpoke.h"
 
+/* DejaGnu should not use gnulib's vsnprintf replacement here.  */
+#undef vsnprintf
+#include <dejagnu.h>
+
 #include "term-if.h"
 
 #define T(name, cond)                                                         \
